package ip;


public interface IPAddress {

	/**
	 * Returns a string representation of the IP address, e.g. "192.168.0.1"
	 */
	public String toString();

	/**
	 * Compares this IPAddress to the specified object
	 * 
	 * @param other
	 *            the IPAddress to compare this string against
	 * @return <code>true</code> if both IPAddress objects represent the same IP
	 *         address, <code>false</code> otherwise.
	 */
	public boolean equals(IPAddress other);

	/**
	 * Returns one of the four parts of the IP address. The parts are indexed
	 * from left to right. For example, in the IP address 192.168.0.1 part 0 is
	 * 192, part 1 is 168, part 2 is 0 and part 3 is 1.
	 * 
	 * @param index
	 *            The index of the IP address part (0, 1, 2 or 3)
	 * @return The value of the specified part.
	 */
	public int getOctet(int index);

	/**
	 * Mask the current address with the given one. The masking operation is a
	 * bitwise 'and' operation on all four parts of the address.
	 * 
	 * @param mask
	 *            the IP address with which to mask
	 * @return A new IP address representing the result of the mask operation.
	 *         The current address is not modified.
	 */
	public IPAddress mask(IPAddress mask);
}
